@@ -6,19 +6,6 @@
 #' @keywords ISO identifier
 #' @return Object of \code{\link{R6Class}} for modelling an ISO Identifier
 #' @format \code{\link{R6Class}} object.
-#'
-#' @field authority [\code{\link{ISOCitation}}] authority
-#' @field code [\code{\link{character}}] code
-#'
-#' @section Methods:
-#' \describe{
-#'  \item{\code{new(xml, code, codeSpace)}}{
-#'    This method is used to instantiate an \code{\link{ISOIdentifier}}
-#'  }
-#'  \item{\code{setAuthority(authority)}}{
-#'    Sets an authority object of class \code{\link{ISOCitation}}
-#'  }
-#' }
 #' 
 #' @note Abstract ISO class
 #' 
@@ -34,18 +21,23 @@ ISOIdentifier <- R6Class("ISOIdentifier",
      xmlNamespacePrefix = "GMD"
    ),
    public = list(
-     #+ authority [0..1]: ISOCitation
+     #'@field authority authority [0..1]: ISOCitation
      authority = NULL,
-     #+ code[1..1]: character
+     #'@field code code[1..1]: character
      code = NULL,
-     initialize = function(xml = NULL, code){
+     
+     #'@description Initializes object
+     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param code code
+     initialize = function(xml = NULL, code = NULL){
        super$initialize(xml = xml)
        if(is.null(xml)){
          self$code <- code
        }
      },
      
-     #setAuthority
+     #'@description Set authority
+     #'@param authority object of class \link{ISOCitation}
      setAuthority = function(authority){
        if(!is(authority, "ISOCitation")){
          stop("The argument should be an object of class 'ISOCitation")
