@@ -8,7 +8,7 @@
 #' @format \code{\link{R6Class}} object.
 #' 
 #' @references 
-#'   OGC Geography Markup Language. https://www.ogc.org/standards/swecommon
+#'   SWE Common Data Model Encoding Standard. https://www.ogc.org/standards/swecommon
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -20,6 +20,9 @@ SWEAbstractSimpleComponent <- R6Class("SWEAbstractSimpleComponent",
   ),
   public = list(
     
+    #'@field nilValues nil values
+    nilValues = NULL,
+    
     #'@description Initializes an object of class \link{SWEAbstractSimpleComponent}
     #'@param xml object of class \link{XMLInternalNode-class} from \pkg{XML}
     #'@param element element
@@ -29,6 +32,12 @@ SWEAbstractSimpleComponent <- R6Class("SWEAbstractSimpleComponent",
     initialize = function(xml = NULL, element = NULL, updatable = NULL, optional = FALSE, definition = NULL){
       if(is.null(element)) element <- private$xmlElement
       super$initialize(xml, element = element, updatable = updatable, optional = optional, definition = definition)
+    },
+    
+    #'@description Set nil value and its reason (optional)
+    #'@param nilValue value to set as nil Value. object of class \code{numeric}
+    setNilValues = function(nilValue){
+      self$nilValues = SWENilValues$new(value = nilValue)
     }
   )                        
 )
\ No newline at end of file
