@@ -9,8 +9,6 @@ require(testthat)
 context("ISOBaseDate")
 
 test_that("encoding",{
-  testthat::skip_on_cran()
-  testthat::skip_on_travis()
   #encoding
   md <- ISOBaseDate$new(value = ISOdate(2015, 1, 1, 1))
   expect_is(md, "ISOBaseDate")
