@@ -62,7 +62,7 @@ test_that("encoding",{
   src$setCitation(cit)
   extent <- ISOExtent$new()
   bbox <- ISOGeographicBoundingBox$new(minx = -180, miny = -90, maxx = 180, maxy = 90)
-  extent$setGeographicElement(bbox)
+  extent$addGeographicElement(bbox)
   src$addExtent(extent)
   lineage$addSource(src)
   
@@ -180,7 +180,7 @@ test_that("encoding - i18n",{
   
   extent <- ISOExtent$new()
   bbox <- ISOGeographicBoundingBox$new(minx = -180, miny = -90, maxx = 180, maxy = 90)
-  extent$setGeographicElement(bbox)
+  extent$addGeographicElement(bbox)
   src$addExtent(extent)
   lineage$addSource(src)
   
