@@ -59,7 +59,7 @@ test_that("encoding/decoding",{
   geomObject <- ISOGeometricObjects$new()
   geomObject$setGeometricObjectType("surface")
   geomObject$setGeometricObjectCount(5L)
-  vsr$setGeometricObjects(geomObject)
+  vsr$addGeometricObjects(geomObject)
   expect_true(md$addSpatialRepresentationInfo(vsr))
   expect_false(md$addSpatialRepresentationInfo(vsr))
   geomObject$setGeometricObjectCount(6L)
@@ -70,7 +70,7 @@ test_that("encoding/decoding",{
   rs <- ISOReferenceSystem$new()
   rsId <- ISOReferenceIdentifier$new(code = "4326", codeSpace = "EPSG")
   rs$setReferenceSystemIdentifier(rsId)
-  md$setReferenceSystemInfo(rs)
+  md$addReferenceSystemInfo(rs)
   
   #data identification
   #--------------------
@@ -91,9 +91,8 @@ test_that("encoding/decoding",{
   expect_equal(length(ident$status), 3L)
   expect_true(ident$delStatus("final"))
   expect_equal(length(ident$status), 2L)
-  
-  ident$setLanguage("eng")
-  ident$setCharacterSet("utf8")
+  ident$addLanguage("eng")
+  ident$addCharacterSet("utf8")
   ident$addTopicCategory("biota")
   ident$addTopicCategory("oceans")
   
@@ -161,7 +160,7 @@ test_that("encoding/decoding",{
   #maintenance information
   mi <- ISOMaintenanceInformation$new()
   mi$setMaintenanceFrequency("daily")
-  ident$setResourceMaintenance(mi)
+  ident$addResourceMaintenance(mi)
   
   #adding legal constraints
   lc <- ISOLegalConstraints$new()
@@ -193,21 +192,21 @@ test_that("encoding/decoding",{
   extent <- ISOExtent$new()
   #geographic element
   bbox <- ISOGeographicBoundingBox$new(minx = -180, miny = -90, maxx = 180, maxy = 90)
-  extent$setGeographicElement(bbox)
+  extent$addGeographicElement(bbox)
   #vertical element
   vert <- ISOVerticalExtent$new()
   vert$setMinimumValue(0)
   vert$setMaximumValue(500)
   vert$setUnitOfMeasure("m")
-  extent$setVerticalElement(vert)
+  extent$addVerticalElement(vert)
   #temporal element
   te <- ISOTemporalExtent$new()
   start <- ISOdate(2000, 1, 12, 12, 59, 45)
   end <- ISOdate(2010, 8, 22, 13, 12, 43)
   tp <- GMLTimePeriod$new(beginPosition = start, endPosition = end)
   te$setTimePeriod(tp)
-  extent$setTemporalElement(te)
-  ident$setExtent(extent)
+  extent$addTemporalElement(te)
+  ident$addExtent(extent)
   
   #add keywords
   kwds1 <- ISOKeywords$new()
@@ -250,7 +249,7 @@ test_that("encoding/decoding",{
   expect_true(ident$delSpatialRepresentationType("grid"))
   expect_equal(length(ident$spatialRepresentationType), 1L)
   
-  md$setIdentificationInfo(ident)
+  md$addIdentificationInfo(ident)
   
   #Distribution
   #---------------
@@ -264,7 +263,7 @@ test_that("encoding/decoding",{
     or$setProtocol("WWW:LINK-1.0-http--link")
     dto$addOnlineResource(or)
   }
-  distrib$setDigitalTransferOptions(dto)
+  distrib$addDigitalTransferOptions(dto)
   md$setDistributionInfo(distrib)
   
   #Data Quality
@@ -297,7 +296,7 @@ test_that("encoding/decoding",{
   lineage$setStatement("statement")
   dq$setLineage(lineage)
   
-  md$setDataQualityInfo(dq)
+  md$addDataQualityInfo(dq)
   
   #Content Information
   #-------------------------
@@ -320,7 +319,7 @@ test_that("encoding/decoding",{
   rp = ISOResponsibleParty$new()
   rp$setRole("publisher")
   rp$setContactInfo(contact)
-  cit$setCitedResponsibleParty(rp)
+  cit$addCitedResponsibleParty(rp)
   fcd$addFeatureCatalogueCitation(cit)
   
   md$addContentInfo(fcd)
@@ -531,7 +530,7 @@ test_that("encoding/decoding - i18n",{
   geomObject <- ISOGeometricObjects$new()
   geomObject$setGeometricObjectType("surface")
   geomObject$setGeometricObjectCount(5L)
-  vsr$setGeometricObjects(geomObject)
+  vsr$addGeometricObjects(geomObject)
   expect_true(md$addSpatialRepresentationInfo(vsr))
   expect_false(md$addSpatialRepresentationInfo(vsr))
   geomObject$setGeometricObjectCount(6L)
@@ -542,7 +541,7 @@ test_that("encoding/decoding - i18n",{
   rs <- ISOReferenceSystem$new()
   rsId <- ISOReferenceIdentifier$new(code = "4326", codeSpace = "EPSG")
   rs$setReferenceSystemIdentifier(rsId)
-  md$setReferenceSystemInfo(rs)
+  md$addReferenceSystemInfo(rs)
   
   #data identification
   #--------------------
@@ -567,8 +566,8 @@ test_that("encoding/decoding - i18n",{
       RU = "цель",
       ZH = "目的"
     ))
-  ident$setLanguage("eng")
-  ident$setCharacterSet("utf8")
+  ident$addLanguage("eng")
+  ident$addCharacterSet("utf8")
   ident$addTopicCategory("biota")
   ident$addTopicCategory("oceans")
   
@@ -751,12 +750,12 @@ test_that("encoding/decoding - i18n",{
       ZH = "地图概述"
     )
   )
-  ident$setGraphicOverview(go)
+  ident$addGraphicOverview(go)
   
   #maintenance information
   mi <- ISOMaintenanceInformation$new()
   mi$setMaintenanceFrequency("daily")
-  ident$setResourceMaintenance(mi)
+  ident$addResourceMaintenance(mi)
   
   #adding legal constraints
   lc <- ISOLegalConstraints$new()
@@ -787,13 +786,13 @@ test_that("encoding/decoding - i18n",{
   expect_equal(length(lc$useLimitation), 2L)
   expect_equal(length(lc$accessConstraints), 2L)
   expect_equal(length(lc$useConstraints), 2L)
-  ident$setResourceConstraints(lc)
+  ident$addResourceConstraints(lc)
   
   #adding extent
   extent <- ISOExtent$new()
   bbox <- ISOGeographicBoundingBox$new(minx = -180, miny = -90, maxx = 180, maxy = 90)
-  extent$setGeographicElement(bbox)
-  ident$setExtent(extent)
+  extent$addGeographicElement(bbox)
+  ident$addExtent(extent)
   
   #add keywords
   kwds <- ISOKeywords$new()
@@ -845,7 +844,7 @@ test_that("encoding/decoding - i18n",{
       ZH = "附加信息"
     ))
   
-  md$setIdentificationInfo(ident)
+  md$addIdentificationInfo(ident)
   
   #Distribution
   #---------------
@@ -885,7 +884,7 @@ test_that("encoding/decoding - i18n",{
       ZH="protocol_ZH"
     ))
   dto$addOnlineResource(or)
-  distrib$setDigitalTransferOptions(dto)
+  distrib$addDigitalTransferOptions(dto)
   
   #format
   format <- ISOFormat$new()
@@ -980,7 +979,7 @@ test_that("encoding/decoding - i18n",{
     ))
   dq$setLineage(lineage)
   
-  md$setDataQualityInfo(dq)
+  md$addDataQualityInfo(dq)
   
   #Content Information
   #-------------------------
@@ -1021,7 +1020,7 @@ test_that("encoding/decoding - i18n",{
   rp = ISOResponsibleParty$new()
   rp$setRole("publisher")
   rp$setContactInfo(contact)
-  cit$setCitedResponsibleParty(rp)
+  cit$addCitedResponsibleParty(rp)
   fcd$addFeatureCatalogueCitation(cit)
   
   md$addContentInfo(fcd)
